@@ -21,6 +21,7 @@ import org.apache.calcite.avatica.remote.AuthenticationType;
 import org.apache.calcite.avatica.remote.Driver.Serialization;
 import org.apache.calcite.avatica.remote.Service;
 import org.apache.calcite.avatica.remote.Service.RpcMetadataResponse;
+import org.apache.calcite.avatica.util.SecurityUtils;
 
 import org.eclipse.jetty.security.Authenticator;
 import org.eclipse.jetty.security.ConfigurableSpnegoLoginService;
@@ -53,7 +54,6 @@ import java.io.File;
 import java.net.InetAddress;
 import java.net.UnknownHostException;
 import java.security.Principal;
-import java.security.PrivilegedAction;
 import java.security.SecureRandom;
 import java.time.Duration;
 import java.util.ArrayList;
@@ -79,6 +79,7 @@ import javax.security.auth.login.LoginException;
 public class HttpServer {
   private static final Logger LOG = LoggerFactory.getLogger(HttpServer.class);
   private static final int MAX_ALLOWED_HEADER_SIZE = 1024 * 64;
+  private static final int MAX_SESSION_INACTIVE_INTERVAL = 60 * 60;
 
   private static final String DEFAULT_KEYSTORE_TYPE = "JKS";
 
@@ -204,8 +205,8 @@ public class HttpServer {
   public void start() {
     if (null != subject) {
       // Run the start in the privileged block (as the kerberos-identified user)
-      Subject.doAs(subject, new PrivilegedAction<Void>() {
-        @Override public Void run() {
+      SecurityUtils.callAs(subject, new Callable<Void>() {
+        @Override public Void call() {
           internalStart();
           return null;
         }
@@ -288,6 +289,9 @@ public class HttpServer {
       securityHandler.setHandler(handler);
       // SPNEGO requires a session
       SessionHandler sessionHandler = new SessionHandler();
+      // We could make this configurable, but the only downside of expiring the session is
+      // forcing re-autentication
+      sessionHandler.setMaxInactiveInterval(MAX_SESSION_INACTIVE_INTERVAL);
       sessionHandler.setHandler(securityHandler);
       avaticaHandler = sessionHandler;
     }
